pub struct AuthErrorResponse {
pub error: String,
}Expand description
This is one possible error response that Zoho might send back when requesting a token. If
the API response contains an error field, it will be treated as an AuthErrorResponse
and should be handled accordingly.
Fields
error: StringTrait Implementations
Sourceimpl Debug for AuthErrorResponse
impl Debug for AuthErrorResponse
Sourceimpl<'de> Deserialize<'de> for AuthErrorResponse
impl<'de> Deserialize<'de> for AuthErrorResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more